@@ -1,14 +1,23 @@
+#' @export
 reykjanes_lava_flow_url <- paste0(
   "https://arcgisserver.isor.is:6443/arcgis/rest/services/",
   "vi/uttekt_eldstodva_allt_2/MapServer/5"
 )
 
+#' @export
 wi_landcover_url <- paste0(
   "https://dnrmaps.wi.gov/arcgis_image/rest/services/",
   "DW_Land_Cover/EN_Land_Cover2_Lev2/MapServer"
 )
 
+#' @export
 wi_leaf_off_url <- paste0(
   "https://dnrmaps.wi.gov/arcgis_image/rest/services/",
-  "DW_Image/EN_Image_Basemap_Leaf_Off/ImageServer"
+  "DW_Imagery/EN_Image_Basemap_Latest_Leaf_Off/ImageServer"
+)
+
+#' @export
+wi_hydro_url <- paste0(
+  "https://dnrmaps.wi.gov/arcgis/rest/services/",
+  "WT_SWDV/WT_Inland_Water_Resources_WTM_Ext_v2/MapServer/2"
 )
